Noora.Card (noora v0.47.0)
A card component, used to separate content into sections.
Example
<.card icon="layers" title="Overview">
<.card_section>
<p>Content goes here</p>
</.card_section>
</.card>
Summary
Functions
The main card container.
A generic wrapper around a piece of content to be displayed in a card. Each card can contain multiple content sections.
Functions
The main card container.
Attributes
icon(:string) (required) - The icon to display in the card.title(:string) (required) - The title of the card.- Global attributes are accepted.
Slots
actions- Slots for actions to be displayed in the card. Rendered to the right of the title.inner_block(required)
A generic wrapper around a piece of content to be displayed in a card. Each card can contain multiple content sections.
Attributes
class(:string) - The class to apply to the card section. Defaults to"".- Global attributes are accepted.
Slots
inner_block(required)