Noora.Tag (noora v0.47.0)
A tag component.
It can optionally be rendered with an icon and a button to dismiss it.
Example
<.tag label="Active" />
<.tag label="User" icon="user" />
<.tag label="Beta" dismissible={true} on_dismiss="remove_tag" dismiss_value="beta" />
Summary
Functions
Attributes
label(:string) (required) - The label of the tag.dismissible(:boolean) - Whether the tag can be dismissed. Defaults tofalse.on_dismiss(:string) - The event to trigger when the tag is dismissed. Defaults tonil.dismiss_value(:string) - Value to pass to the dismiss event. Defaults tonil.disabled(:boolean) - Whether the tag is disabled. Defaults tofalse.- Global attributes are accepted.
Attributes
label(:string) (required) - The label of the tag.dismissible(:boolean) - Whether the tag can be dismissed. Defaults tofalse.on_dismiss(:string) - The event to trigger when the tag is dismissed. Defaults tonil.dismiss_value(:string) - Value to pass to the dismiss event. Defaults tonil.icon(:string) - An icon to render in front of the label. Defaults tonil.disabled(:boolean) - Whether the tag is disabled. Defaults tofalse.- Global attributes are accepted.